@@ -443,7 +443,10 @@ class Client:
             raise ValueError(r.text)
 
     def list_jobs(
-        self, page_size: Optional[int] = 100, order_by: Optional[str] = "-time_started"
+        self,
+        page_size: Optional[int] = 100,
+        page_number: Optional[int] = None,
+        order_by: Optional[str] = "-time_started",
     ) -> ListJobs:
         """List all jobs."""
         if order_by not in LIST_JOBS_ORDER_BY:
@@ -460,6 +463,9 @@ class Client:
         }
         params = {"page_size": page_size, "order_by": order_by}
 
+        if page_number is not None:
+            params["page"] = page_number
+
         r = requests.get(
             "https://wordcab.com/api/v1/jobs",
             headers=headers,
@@ -526,7 +532,9 @@ class Client:
         else:
             raise ValueError(r.text)
 
-    def list_transcripts(self, page_size: Optional[int] = 100) -> ListTranscripts:
+    def list_transcripts(
+        self, page_size: Optional[int] = 100, page_number: Optional[int] = None
+    ) -> ListTranscripts:
         """List all transcripts."""
         headers = {
             "Authorization": f"Bearer {self.api_key}",
@@ -534,6 +542,9 @@ class Client:
         }
         params = {"page_size": page_size}
 
+        if page_number is not None:
+            params["page"] = page_number
+
         r = requests.get(
             "https://wordcab.com/api/v1/transcripts",
             headers=headers,
@@ -598,7 +609,9 @@ class Client:
         else:
             raise ValueError(r.text)
 
-    def list_summaries(self, page_size: Optional[int] = 100) -> ListSummaries:
+    def list_summaries(
+        self, page_size: Optional[int] = 100, page_number: Optional[int] = None
+    ) -> ListSummaries:
         """List all summaries."""
         headers = {
             "Authorization": f"Bearer {self.api_key}",
@@ -606,6 +619,9 @@ class Client:
         }
         params = {"page_size": page_size}
 
+        if page_number is not None:
+            params["page"] = page_number
+
         r = requests.get(
             "https://wordcab.com/api/v1/summaries",
             headers=headers,
